# coding: utf-8

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!   # noqa: E501

    The version of the OpenAPI document: 0.4.16
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import carbon3d
from carbon3d.models.model_resolve_upload_request import ModelResolveUploadRequest  # noqa: E501
from carbon3d.rest import ApiException

class TestModelResolveUploadRequest(unittest.TestCase):
    """ModelResolveUploadRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ModelResolveUploadRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = carbon3d.models.model_resolve_upload_request.ModelResolveUploadRequest()  # noqa: E501
        if include_optional :
            return ModelResolveUploadRequest(
                filename = '/foo/bar.stl', 
                model_etag = '0d91598cfea8838a728590bd7d6a353d', 
                model_uuid = 'aaaaaaaa-f340-4da2-8784-bddd4065e75c', 
                external_id = '3ec320f4-f248-11ed-a05b-0242ac120003'
            )
        else :
            return ModelResolveUploadRequest(
                filename = '/foo/bar.stl',
                model_etag = '0d91598cfea8838a728590bd7d6a353d',
                model_uuid = 'aaaaaaaa-f340-4da2-8784-bddd4065e75c',
        )

    def testModelResolveUploadRequest(self):
        """Test ModelResolveUploadRequest"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
