# coding: utf-8

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!   # noqa: E501

    The version of the OpenAPI document: 0.4.16
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import carbon3d
from carbon3d.models.print_data_qa import PrintDataQa  # noqa: E501
from carbon3d.rest import ApiException

class TestPrintDataQa(unittest.TestCase):
    """PrintDataQa unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PrintDataQa
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = carbon3d.models.print_data_qa.PrintDataQa()  # noqa: E501
        if include_optional :
            return PrintDataQa(
                print_id = '0', 
                printer_id = '0', 
                total_slices = '0', 
                cassette_name = '0', 
                estimated_print_time__ms = '0', 
                resin_exposure_compensation = '0', 
                base_exposure_multiplier = '0', 
                heater_setpoint__c = '0', 
                printer_serial = '0', 
                project_id = '0', 
                print_number = '0', 
                software_version = '0', 
                printer_name = '0', 
                ffb_enabled_print = '0', 
                hardware_profile = '0', 
                cassette_serial = '0', 
                window_serial = '0', 
                platform_serial = '0', 
                resin_name = '0', 
                blackline__um = '0', 
                estimated_consumed_resin_volume__ml = '0', 
                minimum_required_resin_volume__ml = '0', 
                script_name = '0', 
                project_name = '0', 
                print_finished_status = '0', 
                print_alerts = '0', 
                started_date_time = '0', 
                finished_date_time = '0', 
                total_time__min = '0', 
                move_time__min = '0', 
                exposure_time_total__min = '0', 
                total_delay_time__min = '0', 
                light_engine_intensity__m_w_cm2 = '0', 
                current_to_light_engine__m_a = '0', 
                avg_o2_partial_pressure_at_window__ = '0', 
                avg_o2_concentration__ = '0', 
                avg_o2_flow__ml_min = '0', 
                estimated_resin_volume__ml = '0', 
                slice_thickness__um = '0', 
                build_height__mm = '0', 
                created_at = '0', 
                peak_wavelength__nm = '0', 
                resin_alpha = '0', 
                resin_dc = '0', 
                resin_fc = '0', 
                resin_viscosity = '0', 
                light_engine_turned_on = '0'
            )
        else :
            return PrintDataQa(
        )

    def testPrintDataQa(self):
        """Test PrintDataQa"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
