# coding: utf-8

"""
    Carbon DLS API

    Welcome to the Carbon DLS API docs!   # noqa: E501

    The version of the OpenAPI document: 0.4.16
    Contact: api-list@carbon3d.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import carbon3d
from carbon3d.models.model_program_run import ModelProgramRun  # noqa: E501
from carbon3d.rest import ApiException

class TestModelProgramRun(unittest.TestCase):
    """ModelProgramRun unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ModelProgramRun
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = carbon3d.models.model_program_run.ModelProgramRun()  # noqa: E501
        if include_optional :
            return ModelProgramRun(
                status = 'complete', 
                progress = 0, 
                model_uuid = '0', 
                failure_message = '0', 
                uuid = '0', 
                operation_status = [
                    {"external_id":"operation_external_id","status":"complete","progress":1,"model_uuid":"3427f879-4a36-409a-b09c-4196cb2f5cd0","failure_message":null}
                    ]
            )
        else :
            return ModelProgramRun(
                status = 'complete',
                progress = 0,
        )

    def testModelProgramRun(self):
        """Test ModelProgramRun"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
